camelot.camelot.view.export.excel.ExcelExport

Package camelot :: Package camelot :: Package view :: Package export :: Module excel :: Class ExcelExport |
[hide private]
[frames] | no frames]

# Class ExcelExport

source code

Instance Methods | [hide private]
exportToFile(self, filename, title, headerList, dataList) | source code

Method Details | [hide private]

### exportToFile(self, filename, title, headerList, dataList) | source code
Parameters: `filename` - the file to which to save the exported excel `title` - title to put in the first row of the genarated excel file `headerList` - list of header definitions `dataList` - list or generator with the row data